Enum WEnum

pub enum WEnum<T> {
    Value(T),
    Unknown(u32),
}
Available on crate feature wayland and Linux only.
An enum value in the protocol.

Variants



Value(T)

The interpreted value



Unknown(u32)

The stored value does not match one defined by the protocol file

Implementations



impl<T> WEnum<T>

pub fn into_result(self) -> Result<T, WEnumError>

Convert this WEnum into a result

This can be used to take advantage of the numerous helper methods on Result if you don’t plan to handle the unknown case of this enum.

You can also use the From and Into traits to perform the same conversion.