Struct ProtocolError
pub struct ProtocolError {
pub code: u32,
pub object_id: u32,
pub object_interface: String,
pub message: String,
}Available on crate feature
wayland and Linux only.Expand description
A protocol error
This kind of error is generated by the server if your client didn’t respect the protocol, after which the server will kill your connection.
Fields
code: u32The error code associated with the error
It should be interpreted as an instance of the Error enum of the
associated interface.
object_id: u32The id of the object that caused the error
object_interface: StringThe interface of the object that caused the error
message: StringThe message sent by the server describing the error